@@ -1,6 +1,6 @@
 from sickchill import settings
 from sickchill.oldbeard import helpers
-from sickchill.oldbeard.notifiers import (
+from sickchill.oldbeard.notifiers import (  # twilio_notify,
     boxcar2,
     discord,
     emailnotify,
@@ -26,7 +26,6 @@ from sickchill.oldbeard.notifiers import (
     telegram,
     trakt,
     tweet,
-    twilio_notify,
 )
 
 # home theater / nas
@@ -52,7 +51,7 @@ telegram_notifier = telegram.Notifier()
 join_notifier = join.Notifier()
 # social
 twitter_notifier = tweet.Notifier()
-twilio_notifier = twilio_notify.Notifier()
+# twilio_notifier = twilio_notify.Notifier()
 trakt_notifier = trakt.Notifier()
 email_notifier = emailnotify.Notifier()
 slack_notifier = slack.Notifier()
@@ -78,7 +77,7 @@ notifiers = [
     pushalot_notifier,
     pushbullet_notifier,
     twitter_notifier,
-    twilio_notifier,
+    # twilio_notifier,
     trakt_notifier,
     email_notifier,
     slack_notifier,
