@@ -7,8 +7,14 @@ import dateutil.parser
 import sickchill
 from sickchill import logger, settings
 from sickchill.helper.common import sanitize_filename
-from sickchill.helper.exceptions import (CantRefreshShowException, CantRemoveShowException, CantUpdateShowException, EpisodeDeletedException,
-                                         MultipleShowObjectsException, ShowDirectoryNotFoundException)
+from sickchill.helper.exceptions import (
+    CantRefreshShowException,
+    CantRemoveShowException,
+    CantUpdateShowException,
+    EpisodeDeletedException,
+    MultipleShowObjectsException,
+    ShowDirectoryNotFoundException,
+)
 from sickchill.oldbeard.trakt_api import TraktAPI
 from sickchill.show.Show import Show
 from sickchill.tv import TVShow
@@ -22,7 +28,7 @@ from .helpers import chmodAsParent, makeDir, sortable_name
 class ShowQueue(generic_queue.GenericQueue):
     def __init__(self):
         super(ShowQueue, self).__init__()
-        self.queue_name = 'SHOWQUEUE'
+        self.queue_name = "SHOWQUEUE"
 
     def _is_in_queue(self, show, actions):
         if not show:
@@ -76,18 +82,16 @@ class ShowQueue(generic_queue.GenericQueue):
     def update_show(self, show, force=False):
 
         if self.is_being_added(show):
-            raise CantUpdateShowException(
-                '{0} is still being added, wait until it is finished before you update.'.format(show.name)
-            )
+            raise CantUpdateShowException("{0} is still being added, wait until it is finished before you update.".format(show.name))
 
         if self.is_being_updated(show):
             raise CantUpdateShowException(
-                '{0} is already being updated by Post-processor or manually started, can\'t update again until it\'s done.'.format(show.name)
+                "{0} is already being updated by Post-processor or manually started, can't update again until it's done.".format(show.name)
             )
 
         if self.is_in_update_queue(show):
             raise CantUpdateShowException(
-                '{0} is in process of being updated by Post-processor or manually started, can\'t update again until it\'s done.'.format(show.name)
+                "{0} is in process of being updated by Post-processor or manually started, can't update again until it's done.".format(show.name)
             )
 
         queue_item_obj = QueueItemUpdate(show, force=force)
@@ -97,18 +101,19 @@ class ShowQueue(generic_queue.GenericQueue):
     def refresh_show(self, show, force=False):
 
         if self.is_being_refreshed(show) and not force:
-            raise CantRefreshShowException('This show is already being refreshed, not refreshing again.')
+            raise CantRefreshShowException("This show is already being refreshed, not refreshing again.")
 
         if self.is_being_updated(show) or self.is_in_update_queue(show):
             logger.debug(
-                'A refresh was attempted but there is already an update queued or in progress. Updates do a refresh at the end so I\'m skipping this request.')
+                "A refresh was attempted but there is already an update queued or in progress. Updates do a refresh at the end so I'm skipping this request."
+            )
             return
 
         if show.paused and not force:
-            logger.debug('Skipping show [{0}] because it is paused.'.format(show.name))
+            logger.debug("Skipping show [{0}] because it is paused.".format(show.name))
             return
 
-        logger.debug('Queueing show refresh for {0}'.format(show.name))
+        logger.debug("Queueing show refresh for {0}".format(show.name))
 
         queue_item_obj = QueueItemRefresh(show, force=force)
         self.add_item(queue_item_obj)
@@ -127,9 +132,25 @@ class ShowQueue(generic_queue.GenericQueue):
         return queue_item_obj
 
     # noinspection PyPep8Naming
-    def add_show(self, indexer, indexer_id, showDir, default_status=None, quality=None, season_folders=None,
-                 lang=None, subtitles=None, subtitles_sr_metadata=None, anime=None, scene=None, paused=None,
-                 blacklist=None, whitelist=None, default_status_after=None, root_dir=None):
+    def add_show(
+        self,
+        indexer,
+        indexer_id,
+        showDir,
+        default_status=None,
+        quality=None,
+        season_folders=None,
+        lang=None,
+        subtitles=None,
+        subtitles_sr_metadata=None,
+        anime=None,
+        scene=None,
+        paused=None,
+        blacklist=None,
+        whitelist=None,
+        default_status_after=None,
+        root_dir=None,
+    ):
 
         if lang is None:
             lang = settings.INDEXER_DEFAULT_LANGUAGE
@@ -137,22 +158,37 @@ class ShowQueue(generic_queue.GenericQueue):
         if default_status_after is None:
             default_status_after = settings.STATUS_DEFAULT_AFTER
 
-        queue_item_obj = QueueItemAdd(indexer, indexer_id, showDir, default_status, quality, season_folders, lang,
-                                      subtitles, subtitles_sr_metadata, anime, scene, paused, blacklist, whitelist,
-                                      default_status_after, root_dir)
+        queue_item_obj = QueueItemAdd(
+            indexer,
+            indexer_id,
+            showDir,
+            default_status,
+            quality,
+            season_folders,
+            lang,
+            subtitles,
+            subtitles_sr_metadata,
+            anime,
+            scene,
+            paused,
+            blacklist,
+            whitelist,
+            default_status_after,
+            root_dir,
+        )
 
         self.add_item(queue_item_obj)
         return queue_item_obj
 
     def remove_show(self, show, full=False):
         if not show:
-            raise CantRemoveShowException('Failed removing show: Show does not exist')
+            raise CantRemoveShowException("Failed removing show: Show does not exist")
 
-        if not hasattr(show, 'indexerid'):
-            raise CantRemoveShowException('Failed removing show: Show does not have an indexer id')
+        if not hasattr(show, "indexerid"):
+            raise CantRemoveShowException("Failed removing show: Show does not have an indexer id")
 
         if self._is_in_queue(show, (ShowQueueActions.REMOVE,)):
-            raise CantRemoveShowException('{0} is already queued to be removed'.format(show.name))
+            raise CantRemoveShowException("{0} is already queued to be removed".format(show.name))
 
         # remove other queued actions for this show.
         for item in self.queue:
@@ -165,7 +201,6 @@ class ShowQueue(generic_queue.GenericQueue):
 
 
 class ShowQueueActions(object):
-
     def __init__(self):
         pass
 
@@ -178,13 +213,13 @@ class ShowQueueActions(object):
     REMOVE = 7
 
     names = {
-        REFRESH: _('Refresh'),
-        ADD: _('Add'),
-        UPDATE: _('Update'),
-        FORCEUPDATE: _('Force Update'),
-        RENAME: _('Rename'),
-        SUBTITLE: _('Subtitle'),
-        REMOVE: _('Remove Show')
+        REFRESH: _("Refresh"),
+        ADD: _("Add"),
+        UPDATE: _("Update"),
+        FORCEUPDATE: _("Force Update"),
+        RENAME: _("Rename"),
+        SUBTITLE: _("Subtitle"),
+        REMOVE: _("Remove Show"),
     }
 
 
@@ -205,12 +240,11 @@ class ShowQueueItem(generic_queue.QueueItem):
         self.show = show
 
     def is_in_queue(self):
-        return self in settings.showQueueScheduler.action.queue + [
-            settings.showQueueScheduler.action.currentItem]
+        return self in settings.showQueueScheduler.action.queue + [settings.showQueueScheduler.action.currentItem]
 
     @property
     def show_name(self):
-        return self.show.name if self.show else 'UNSET'
+        return self.show.name if self.show else "UNSET"
 
     @property
     def is_loading(self):
@@ -219,10 +253,25 @@ class ShowQueueItem(generic_queue.QueueItem):
 
 class QueueItemAdd(ShowQueueItem):
     # noinspection PyPep8Naming
-    def __init__(self,
-                 indexer, indexer_id, showDir, default_status, quality, season_folders,
-                 lang, subtitles, subtitles_sr_metadata, anime, scene, paused, blacklist, whitelist,
-                 default_status_after, root_dir):
+    def __init__(
+        self,
+        indexer,
+        indexer_id,
+        showDir,
+        default_status,
+        quality,
+        season_folders,
+        lang,
+        subtitles,
+        subtitles_sr_metadata,
+        anime,
+        scene,
+        paused,
+        blacklist,
+        whitelist,
+        default_status_after,
+        root_dir,
+    ):
 
         super(QueueItemAdd, self).__init__(ShowQueueActions.ADD, None)
 
@@ -266,29 +315,43 @@ class QueueItemAdd(ShowQueueItem):
 
     @property
     def info(self):
-        info = namedtuple('LoadingShowInfo', 'id name sort_name network network_image_url show_image_url quality')
+        info = namedtuple("LoadingShowInfo", "id name sort_name network network_image_url show_image_url quality")
         if self.show:
-            return info(id=self.show.indexerid, name=self.show.name, sort_name=self.show.sort_name, network=self.show.network,
-                        network_image_url=self.show.network_image_url, show_image_url=self.show.show_image_url, quality=self.show.quality)
+            return info(
+                id=self.show.indexerid,
+                name=self.show.name,
+                sort_name=self.show.sort_name,
+                network=self.show.network,
+                network_image_url=self.show.network_image_url,
+                show_image_url=self.show.show_image_url,
+                quality=self.show.quality,
+            )
         # noinspection PyUnresolvedReferences
-        return info(id=0, name=self.show_name, sort_name=sortable_name(self.show_name), network=_('Loading'),
-                    network_image_url='images/network/nonetwork.png', show_image_url=lambda x, include_date=False: 'images/{}.png'.format(('poster', 'banner')['banner' in x]),
-                    quality=0)
+        return info(
+            id=0,
+            name=self.show_name,
+            sort_name=sortable_name(self.show_name),
+            network=_("Loading"),
+            network_image_url="images/network/nonetwork.png",
+            show_image_url=lambda x: "images/{}.png".format(("poster", "banner")["banner" in x]),
+            quality=0,
+        )
 
     def run(self):
 
         super(QueueItemAdd, self).run()
 
-        logger.info(_('Starting to add show {0}').format(_('by ShowDir: {0}').format(self.showDir) if self.showDir else _('by Indexer Id: {0}').format(self.indexer_id)))
+        logger.info(
+            _("Starting to add show {0}").format(_("by ShowDir: {0}").format(self.showDir) if self.showDir else _("by Indexer Id: {0}").format(self.indexer_id))
+        )
         # make sure the Indexer IDs are valid
         try:
             s = sickchill.indexer.series_by_id(indexerid=self.indexer_id, indexer=self.indexer, language=self.lang)
             if not s:
-                error_string = _('Could not find show with id:{0} on {1}, skipping').format(
-                    self.indexer_id, sickchill.indexer.name(self.indexer))
+                error_string = _("Could not find show with id:{0} on {1}, skipping").format(self.indexer_id, sickchill.indexer.name(self.indexer))
 
                 logger.info(error_string)
-                ui.notifications.error(_('Unable to add show'), error_string)
+                ui.notifications.error(_("Unable to add show"), error_string)
 
                 self._finish_early()
                 return
@@ -297,18 +360,18 @@ class QueueItemAdd(ShowQueueItem):
             # Indexers provided series name
             if self.root_dir and not self.showDir:
                 if not s.seriesName:
-                    logger.info(_('Unable to get a show {0}, can\'t add the show').format(self.showDir))
+                    logger.info(_("Unable to get a show {0}, can't add the show").format(self.showDir))
                     self._finish_early()
                     return
 
                 show_dir = s.seriesName
                 if settings.ADD_SHOWS_WITH_YEAR and s.firstAired:
                     try:
-                        year = '({0})'.format(dateutil.parser.parse(s.firstAired).year)
+                        year = "({0})".format(dateutil.parser.parse(s.firstAired).year)
                         if year not in show_dir:
-                            show_dir = '{0} {1}'.format(s.seriesName, year)
+                            show_dir = "{0} {1}".format(s.seriesName, year)
                     except (TypeError, ValueError):
-                        logger.info(_('Could not append the show year folder for the show: {0}').format(show_dir))
+                        logger.info(_("Could not append the show year folder for the show: {0}").format(show_dir))
 
                 self.showDir = os.path.join(self.root_dir, sanitize_filename(show_dir))
 
@@ -317,43 +380,38 @@ class QueueItemAdd(ShowQueueItem):
                 else:
                     dir_exists = makeDir(self.showDir)
                     if not dir_exists:
-                        logger.info(_('Unable to create the folder {0}, can\'t add the show').format(self.showDir))
+                        logger.info(_("Unable to create the folder {0}, can't add the show").format(self.showDir))
                         self._finish_early()
                         return
 
                     chmodAsParent(self.showDir)
 
             # this usually only happens if they have an NFO in their show dir which gave us a Indexer ID that has no proper english version of the show
-            if getattr(s, 'seriesName', None) is None:
+            if getattr(s, "seriesName", None) is None:
                 # noinspection PyPep8
-                error_string = _('Show in {0} has no name on {1}, probably searched with the wrong language. Delete .nfo and add manually in the correct language.').format(
-                    self.showDir, sickchill.indexer.name(self.indexer))
+                error_string = _(
+                    "Show in {0} has no name on {1}, probably searched with the wrong language. Delete .nfo and add manually in the correct language."
+                ).format(self.showDir, sickchill.indexer.name(self.indexer))
 
                 logger.warning(error_string)
-                ui.notifications.error(_('Unable to add show'), error_string)
+                ui.notifications.error(_("Unable to add show"), error_string)
 
                 self._finish_early()
                 return
         except Exception as error:
-            error_string = 'Unable to look up the show in {0} on {1} using ID {2}, not using the NFO. Delete .nfo and try adding manually again.'.format(
-                self.showDir, sickchill.indexer.name(self.indexer), self.indexer_id)
+            error_string = "Unable to look up the show in {0} on {1} using ID {2}, not using the NFO. Delete .nfo and try adding manually again.".format(
+                self.showDir, sickchill.indexer.name(self.indexer), self.indexer_id
+            )
 
-            logger.exception('{0}: {1}'.format(error_string, error))
-            ui.notifications.error(_('Unable to add show'), error_string)
+            logger.exception("{0}: {1}".format(error_string, error))
+            ui.notifications.error(_("Unable to add show"), error_string)
 
             if settings.USE_TRAKT:
                 trakt_api = TraktAPI(settings.SSL_VERIFY, settings.TRAKT_TIMEOUT)
 
-                title = self.showDir.split('/')[-1]
-                data = {
-                    'shows': [
-                        {
-                            'title': title,
-                            'ids': {sickchill.indexer.slug(self.indexer): self.indexer_id}
-                        }
-                    ]
-                }
-                trakt_api.traktRequest('sync/watchlist/remove', data, method='POST')
+                title = self.showDir.split("/")[-1]
+                data = {"shows": [{"title": title, "ids": {sickchill.indexer.slug(self.indexer): self.indexer_id}}]}
+                trakt_api.traktRequest("sync/watchlist/remove", data, method="POST")
 
             self._finish_early()
             return
@@ -385,7 +443,7 @@ class QueueItemAdd(ShowQueueItem):
             self.show.paused = self.paused if self.paused is not None else False
 
             # set up default new/missing episode status
-            logger.info(_('Setting all episodes to the specified default status: {0}') .format(self.show.default_ep_status))
+            logger.info(_("Setting all episodes to the specified default status: {0}").format(self.show.default_ep_status))
             self.show.default_ep_status = self.default_status
 
             if self.show.anime:
@@ -404,23 +462,22 @@ class QueueItemAdd(ShowQueueItem):
             #     self.show.sports = 1
 
         except Exception as error:
-            error_string = 'Unable to add {0} due to an error with {1}'.format(
-                self.show.name if self.show else 'show', sickchill.indexer.name(self.indexer))
+            error_string = "Unable to add {0} due to an error with {1}".format(self.show.name if self.show else "show", sickchill.indexer.name(self.indexer))
 
-            logger.exception('{0}: {1}'.format(error_string, error))
+            logger.exception("{0}: {1}".format(error_string, error))
 
-            logger.exception('Error trying to add show: {0}'.format(error))
+            logger.exception("Error trying to add show: {0}".format(error))
             logger.debug(traceback.format_exc())
 
-            ui.notifications.error(_('Unable to add show'), error_string)
+            ui.notifications.error(_("Unable to add show"), error_string)
 
             self._finish_early()
             return
 
         except MultipleShowObjectsException:
-            error_string = _('The show in {0} is already in your show list, skipping').format(self.showDir)
+            error_string = _("The show in {0} is already in your show list, skipping").format(self.showDir)
             logger.warning(error_string)
-            ui.notifications.error(_('Show skipped'), error_string)
+            ui.notifications.error(_("Show skipped"), error_string)
 
             self._finish_early()
             return
@@ -430,7 +487,7 @@ class QueueItemAdd(ShowQueueItem):
         try:
             self.show.saveToDB()
         except Exception as error:
-            logger.exception('Error saving the show to the database: {0}'.format(error))
+            logger.exception("Error saving the show to the database: {0}".format(error))
             logger.debug(traceback.format_exc())
             self._finish_early()
             raise
@@ -442,7 +499,7 @@ class QueueItemAdd(ShowQueueItem):
         try:
             self.show.loadEpisodesFromIndexer()
         except Exception as error:
-            logger.exception('Error with {0}, not creating episode list: {1}'.format(self.show.idxr.name, error))
+            logger.exception("Error with {0}, not creating episode list: {1}".format(self.show.idxr.name, error))
             logger.debug(traceback.format_exc())
 
         # update internal name cache
@@ -451,13 +508,13 @@ class QueueItemAdd(ShowQueueItem):
         try:
             self.show.loadEpisodesFromDir()
         except Exception as error:
-            logger.exception('Error searching dir for episodes: {0}'.format(error))
+            logger.exception("Error searching dir for episodes: {0}".format(error))
             logger.debug(traceback.format_exc())
 
         # if they set default ep status to WANTED then run the backlog to search for episodes
         # FIXME: This needs to be a backlog queue item!!!
         if self.show.default_ep_status == WANTED:
-            logger.info('Launching backlog for this show since its episodes are WANTED')
+            logger.info("Launching backlog for this show since its episodes are WANTED")
             settings.backlogSearchScheduler.action.searchBacklog([self.show])
 
         self.show.writeMetadata()
@@ -474,7 +531,7 @@ class QueueItemAdd(ShowQueueItem):
                 settings.traktCheckerScheduler.action.addShowToTraktLibrary(self.show)
 
             if settings.TRAKT_SYNC_WATCHLIST:
-                logger.info('update watchlist')
+                logger.info("update watchlist")
                 notifiers.trakt_notifier.update_watchlist(show_obj=self.show)
 
         # Load XEM data to DB for show
@@ -512,7 +569,7 @@ class QueueItemRefresh(ShowQueueItem):
 
         super(QueueItemRefresh, self).run()
 
-        logger.info('Performing refresh on {0}'.format(self.show.name))
+        logger.info("Performing refresh on {0}".format(self.show.name))
 
         self.show.refreshDir()
         self.show.writeMetadata()
@@ -535,12 +592,12 @@ class QueueItemRename(ShowQueueItem):
 
         super(QueueItemRename, self).run()
 
-        logger.info('Performing rename on {0}'.format(self.show.name))
+        logger.info("Performing rename on {0}".format(self.show.name))
 
         try:
             self.show.location
         except ShowDirectoryNotFoundException:
-            logger.warning('Can\'t perform rename on {0} when the show dir is missing.'.format(self.show.name))
+            logger.warning("Can't perform rename on {0} when the show dir is missing.".format(self.show.name))
             super(QueueItemRename, self).finish()
             self.finish()
             return
@@ -578,7 +635,7 @@ class QueueItemSubtitle(ShowQueueItem):
     def run(self):
         super(QueueItemSubtitle, self).run()
 
-        logger.info('Downloading subtitles for {0} '.format(self.show.name))
+        logger.info("Downloading subtitles for {0} ".format(self.show.name))
 
         self.show.download_subtitles()
 
@@ -597,13 +654,13 @@ class QueueItemUpdate(ShowQueueItem):
 
         super(QueueItemUpdate, self).run()
 
-        logger.debug('Beginning update of {0}'.format(self.show.name))
+        logger.debug("Beginning update of {0}".format(self.show.name))
 
-        logger.debug('Retrieving show info from {0}'.format(self.show.idxr.name))
+        logger.debug("Retrieving show info from {0}".format(self.show.idxr.name))
         try:
             self.show.loadFromIndexer()
         except Exception as error:
-            logger.warning('Unable to contact {0}, aborting: {1}'.format(self.show.idxr.name, error))
+            logger.warning("Unable to contact {0}, aborting: {1}".format(self.show.idxr.name, error))
             super(QueueItemUpdate, self).finish()
             self.finish()
             return
@@ -614,19 +671,18 @@ class QueueItemUpdate(ShowQueueItem):
         try:
             self.show.saveToDB()
         except Exception as error:
-            logger.exception('Error saving show info to the database: {0}'.format(error))
+            logger.exception("Error saving show info to the database: {0}".format(error))
             logger.debug(traceback.format_exc())
 
         # get episode list from DB
         DBEpList = self.show.loadEpisodesFromDB()
 
         # get episode list from TVDB
-        logger.debug('Loading all episodes from {0}'.format(self.show.idxr.name))
+        logger.debug("Loading all episodes from {0}".format(self.show.idxr.name))
         try:
             IndexerEpList = self.show.loadEpisodesFromIndexer()
         except Exception as error:
-            logger.exception('Unable to get info from {0}, the show info will not be refreshed: {1}'.format
-                             (self.show.idxr.name, error))
+            logger.exception("Unable to get info from {0}, the show info will not be refreshed: {1}".format(self.show.idxr.name, error))
             IndexerEpList = None
 
         if IndexerEpList:
@@ -641,8 +697,7 @@ class QueueItemUpdate(ShowQueueItem):
             # remaining episodes in the DB list are not on the indexer, just delete them from the DB
             for curSeason in DBEpList:
                 for curEpisode in DBEpList[curSeason]:
-                    logger.info('Permanently deleting episode {0:02d}E{1:02d} from the database'.format
-                                (curSeason, curEpisode))
+                    logger.info("Permanently deleting episode {0:02d}E{1:02d} from the database".format(curSeason, curEpisode))
                     curEp = self.show.getEpisode(curSeason, curEpisode)
                     try:
                         curEp.deleteEpisode()
@@ -653,10 +708,10 @@ class QueueItemUpdate(ShowQueueItem):
         try:
             self.show.saveToDB()
         except Exception as error:
-            logger.exception('Error saving show info to the database: {0}'.format(error))
+            logger.exception("Error saving show info to the database: {0}".format(error))
             logger.debug(traceback.format_exc())
 
-        logger.debug('Finished update of {0}'.format(self.show.name))
+        logger.debug("Finished update of {0}".format(self.show.name))
 
         # oldbeard.showQueueScheduler.action.refresh_show(self.show, self.force)
         QueueItemRefresh(self.show, self.force).run()
@@ -674,14 +729,14 @@ class QueueItemRemove(ShowQueueItem):
 
     def run(self):
         super(QueueItemRemove, self).run()
-        logger.info('Removing {0}'.format(self.show.name))
+        logger.info("Removing {0}".format(self.show.name))
         self.show.deleteShow(full=self.full)
 
         if settings.USE_TRAKT:
             try:
                 settings.traktCheckerScheduler.action.removeShowFromTraktLibrary(self.show)
             except Exception as error:
-                logger.warning(_('Unable to delete show from Trakt: {0}. Error: {1}').format(self.show.name, error))
+                logger.warning(_("Unable to delete show from Trakt: {0}. Error: {1}").format(self.show.name, error))
 
         # If any notification fails, don't stop removal
         try:
